@@ -2,7 +2,7 @@ import requests
 from voxyl.constants import *
 
 def getUUID(ign):
-    mojdata = requests.get(f"{MOJBASE}{MOJUUID}{ign}")
+    mojdata = requests.get(f"{MOJUUID}{ign}")
     
     if mojdata.status_code != 200:
         raise UnknownPlayer(f"Player not found: '{ign}'")
@@ -11,7 +11,7 @@ def getUUID(ign):
     return mojdata["id"]
 
 def getIGN(uuid):
-    mojdata = requests.get(f"{MOJBASE}{MOJIGN}{uuid}")
+    mojdata = requests.get(f"{MOJIGN}{uuid}")
     
     if mojdata.status_code != 200:
         raise UnknownPlayer(f"Player not found: '{uuid}'")
